@@ -11,6 +11,7 @@ from ...caluma_core.relay import extract_global_id
         ("STARTSWITH", "bar", ["exact", "starts"]),
         ("CONTAINS", "bar", ["contains", "starts", "exact"]),
         ("ICONTAINS", "bar", ["icontains", "contains", "starts", "exact"]),
+        ("IN", [1, 2], ["in"]),
         (None, True, ["bool"]),
         (None, 123, ["int"]),
         (None, 123.456, ["float"]),
@@ -25,6 +26,7 @@ def test_meta_value_filter(
         "starts": document_factory(meta={"foo": "bar is what it starts with"}),
         "contains": document_factory(meta={"foo": "contains a bar somewhere"}),
         "icontains": document_factory(meta={"foo": "contains a Bar somewhere"}),
+        "in": document_factory(meta={"foo": 1}),
         "bool": document_factory(meta={"foo": True}),
         "int": document_factory(meta={"foo": 123}),
         "float": document_factory(meta={"foo": 123.456}),
